#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "brlcad/ConstDatabase.h"
#include "displayutil.h"
#include <QMainWindow>
#include <QListWidget>
#include <QLabel>
#include <QPushButton>


namespace Ui {
class MainWindow;
}


class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
	void loadDatabase(const char *fileName);
	void closeDatabase(void);
	void quit(void);

private:
	void debug();
	void setDatabaseName(const char*);
	void setInterfaceVisible(bool);
	void initMenu(void);
	void initUI(void);
	void openFileDialog(void);
	void onObjectDoubleClicked(QListWidgetItem*);
	void onObjectClicked(QListWidgetItem*);
	void rayTrace(const char *object);
	void rayTraceSelectedListItem(void);
	void updateCamera(void);
	void updateCamera(Camera *camera);
	void updateCameraSettings(void);
	void updateCameraSettings(const Camera *camera);
	std::vector<const char*> loadTopLevelObjects(void);

	BRLCAD::ConstDatabase *database;
	QListWidget *objectListWidget;
	QAction *actionOpen, *actionClose, *actionQuit;
	QLabel *mainDisplayWidget;
	QLineEdit *cameraXEdit, *cameraYEdit, *cameraZEdit;
	QLineEdit *cameraDirXEdit, *cameraDirYEdit, *cameraDirZEdit;
	QLineEdit *cameraRotationEdit;
	QLineEdit *cameraWidthEdit, *cameraHeightEdit;
	QLineEdit *rayTracePixelEdit;
	QPushButton *rayTraceButton;
	Camera* mainCamera;
};

#endif // MAINWINDOW_H
